======
whitex
======


.. image:: https://img.shields.io/pypi/v/whitex.svg
        :target: https://pypi.python.org/pypi/whitex

.. image:: https://img.shields.io/travis/ivanovmg/whitex.svg
        :target: https://travis-ci.com/ivanovmg/whitex

.. image:: https://readthedocs.org/projects/whitex/badge/?version=latest
        :target: https://whitex.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Clean up LaTeX files


* Free software: GNU General Public License v3
* Documentation: https://whitex.readthedocs.io.


Features
--------

* TODO

Credits
-------

This project is a fork of `blacktex <https://github.com/nschloe/blacktex>`_.
The present project aims at OOP development.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
